==> haskell-ini-0.4.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ini
version:              0.4.1
visibility:           public
id:                   ini-0.4.1-40ClTiteSej75twVa35GNG
key:                  ini-0.4.1-40ClTiteSej75twVa35GNG
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             http://github.com/chrisdone/ini
synopsis:             Quick and easy configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  dd085a7c33633e69e25df04ac4b02571
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ini-0.4.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ini-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ini-0.4.1
hs-libraries:         HSini-0.4.1-40ClTiteSej75twVa35GNG
depends:
    attoparsec-0.13.2.4-E6tYZWwzvMCzu2pmoxmmw base-4.13.0.0
    text-1.2.4.0 unordered-containers-0.2.10.0-A1cNogzO5wQ33Xk0bjeyDo

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.4.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ini
version:              0.4.1
visibility:           public
id:                   ini-0.4.1-Ajs5zBvIwjs1i5P83zjjuQ
key:                  ini-0.4.1-Ajs5zBvIwjs1i5P83zjjuQ
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             http://github.com/chrisdone/ini
synopsis:             Quick and easy configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  0b8759f88006cc39b81e5d51a87f4e99
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ini-0.4.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ini-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ini-0.4.1
hs-libraries:         HSini-0.4.1-Ajs5zBvIwjs1i5P83zjjuQ
depends:
    attoparsec-0.13.2.4-CwM8a4WQCATLoXuAGiNv3w base-4.14.0.0
    text-1.2.3.2 unordered-containers-0.2.10.0-G13aGNInC3gBl4w7zg86q

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
